@@ -18,6 +18,7 @@ from mediabox_widget.ui.ProgressBar import HProgressBar, SeekBar
 from mediabox_widget.ui.ScrollingText import ScrollingText
 from mediabox_widget.ui.Theme import *
 from mediabox_widget.util.config import *
+from mediabox_widget.util.locale import *
 
 class AbstractMediaBoxWidget():
 
@@ -46,6 +47,7 @@ class AbstractMediaBoxWidget():
 
     self._config = get_config()
     self._mb_config = get_mediabox_config()
+    self._lcl = get_locale()
     self.__config_controls = {}
     self._theme = get_theme()
     self.__mediabox_state = 'unknown'
@@ -82,6 +84,7 @@ class AbstractMediaBoxWidget():
     self.__working = True
     self.connect('destroy', self.__cleanup)
     self.__custom_init__()
+    self.__show_all__()
     self.connection_updated()
     #self.show_settings_dialog()
 
@@ -101,11 +104,11 @@ class AbstractMediaBoxWidget():
         continue
       elif ck_type == bool:
         config_control = hildon.CheckButton(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
-        config_control.set_label(config_key)
+        config_control.set_label(self._lcl.get(config_key))
         config_control.set_active(value)
       elif ck_type == list:
         config_control = hildon.PickerButton(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-        config_control.set_title(config_key)
+        config_control.set_title(self._lcl.get(config_key))
         config_control.set_alignment(0, 0.5, 0, 0)
         config_control.set_value('%s' % (value))
       elif ck_type == tuple:
@@ -114,7 +117,7 @@ class AbstractMediaBoxWidget():
         config_control = hildon.PickerButton(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
       else:
         config_control = hildon.PickerButton(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)#HORIZONTAL)
-        config_control.set_title(config_key)
+        config_control.set_title(self._lcl.get(config_key))
         config_control.set_alignment(0, 0.5, 0, 0)
         config_ts = hildon.TouchSelector()
         config_control.set_selector(config_ts)
@@ -124,10 +127,12 @@ class AbstractMediaBoxWidget():
         config_ts.set_column_selection_mode(hildon.TOUCH_SELECTOR_SELECTION_MODE_SINGLE)
         if config_options:
           for config_option in config_options:
-            config_list_store.append([str(config_option), config_option])
+            config_list_store.append([self._lcl.get(str(config_option)), config_option])
+          if not value in config_options:
+            config_list_store.append([self._lcl.get(str(value)), value])
           config_control.set_active(config_options.index(value))
         else:
-          config_list_store.append([str(value), value])
+          config_list_store.append([self._lcl.get(str(value)), value])
           config_control.set_active(0)
       self.__config_controls[config_key] = config_control
       vbox.add(config_control)
@@ -137,6 +142,10 @@ class AbstractMediaBoxWidget():
     response = settings_dialog.run()
     if response == gtk.RESPONSE_OK:
       self.save_settings()
+      tmp = self._config.get_value('compact-layout')
+      if tmp != self.__compact_view:
+        self.__compact_view = tmp
+        self.__recreate_view()
     settings_dialog.destroy()
 
   def save_settings(self):
@@ -156,6 +165,16 @@ class AbstractMediaBoxWidget():
       self._config.set_value(config_key, value)
     self._config.save()
 
+  def __recreate_view(self):
+    self.remove(self.widget_box)
+    self.widget_box.destroy()
+    if self.__compact_view:
+      self.create_compact_view()
+    else:
+      self.create_view()
+    self.__show_all__()
+    self.connection_updated()
+
   def create_view(self):
     self.size_width = 434
     self.size_height = 216
@@ -200,6 +219,7 @@ class AbstractMediaBoxWidget():
     self.widget_box.set_border_width(self.control_spacing)
     self.add(self.widget_box)
     self.set_size_request(self.size_width, self.size_height)
+    self.resize(self.size_width, self.size_height)
     self.__watch_widgets = (self.track_image, self.track_artist, self.track_title, self.track_album, self.seek_control)
 
   def create_compact_view(self):
@@ -243,6 +263,7 @@ class AbstractMediaBoxWidget():
     self.widget_box.set_border_width(self.control_spacing)
     self.add(self.widget_box)
     self.set_size_request(self.size_width, self.size_height)
+    self.resize(self.size_width, self.size_height)
     self.__watch_widgets = (self.track_text,)
 
   def __super_init__(self):
@@ -251,6 +272,9 @@ class AbstractMediaBoxWidget():
   def __custom_init__(self):
     raise NotImplementedError('AbstractMediaBoxWidget.__custom_init__() must be implemented')
 
+  def __show_all__(self):
+    raise NotImplementedError('AbstractMediaBoxWidget.__show_all__() must be implemented')
+
   def __init_signals(self):
     for key in self.__signals:
       self.__signals[key]['receiver_match'] = self.__bus.add_signal_receiver(self.__signals[key]['cb'], signal_name=self.__signals[key]['signal_name'], dbus_interface=self.__signals[key]['dbus_interface'], path=self.__signals[key]['path'])
@@ -280,7 +304,6 @@ class AbstractMediaBoxWidget():
       self.screen_box.hide()
       self.clear_track_info()
     self.pause_button.hide()
-    self.set_size_request(self.size_width, self.size_height)
 
 #Misc
   def start_mediabox(self, widget=None):
